==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/CassandraPartitionKeyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.CassandraPartitionKeyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Cosmos DB Cassandra table partition key
 * @property name Name of the Cosmos DB Cassandra table partition key
 */
public data class CassandraPartitionKeyArgs(
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.CassandraPartitionKeyArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.CassandraPartitionKeyArgs =
        com.pulumi.azurenative.documentdb.inputs.CassandraPartitionKeyArgs.builder()
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CassandraPartitionKeyArgs].
 */
@PulumiTagMarker
public class CassandraPartitionKeyArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    /**
     * @param value Name of the Cosmos DB Cassandra table partition key
     */
    @JvmName("okiiiugufhovixsy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Name of the Cosmos DB Cassandra table partition key
     */
    @JvmName("fhfgjkjnkjdutlwq")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): CassandraPartitionKeyArgs = CassandraPartitionKeyArgs(
        name = name,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/CassandraPartitionKeyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.CassandraPartitionKeyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Cosmos DB Cassandra table partition key
 * @property name Name of the Cosmos DB Cassandra table partition key
 */
public data class CassandraPartitionKeyArgs(
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.CassandraPartitionKeyArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.CassandraPartitionKeyArgs =
        com.pulumi.azurenative.documentdb.inputs.CassandraPartitionKeyArgs.builder()
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CassandraPartitionKeyArgs].
 */
@PulumiTagMarker
public class CassandraPartitionKeyArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    /**
     * @param value Name of the Cosmos DB Cassandra table partition key
     */
    @JvmName("btlierwpddhnfuyy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Name of the Cosmos DB Cassandra table partition key
     */
    @JvmName("wotdqtwkknxxpvsq")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): CassandraPartitionKeyArgs = CassandraPartitionKeyArgs(
        name = name,
    )
}
